import request from '@/utils/request'
import qs from 'qs';
import { upcloud_base_wh ,upcloud_base_common} from "@/config/serviceSettings";

// 库房管理(主表)/条件分页查询
export function baseWmsWarehouseRoomMst_page(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/page',
    method: 'post',
    data: params,
    headers: {
      'Content-Type': 'application/json;'
    }
  })
}

// 库房管理(主表)/条件分页查询2
export function baseWmsWarehouseRoomMst_page2(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/page2',
    method: 'get',
    params: params,
    headers: {
      'Content-Type': 'x-www-form-urlencoded;'
    }
  })
}

// 库房管理(主表)/ 查询单个(含拓展) GET
export function baseWmsWarehouseRoomMst_infoWithExpand(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/infoWithExpand',
    method: 'get',
    params: params,
    headers: {
      'Content-Type': 'x-www-form-urlencoded;'
    }
  })
}

// /库房(拓展表维护)/条件分页
export function baseWmsWarehouseRoomProfil_page(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomProfil/page',
    method: 'post',
    data: params,
    headers: {
      'Content-Type': 'application/json;'
    }
  })
}

// /库房管理主表/添加 (不含拓展)
export function baseWmsWarehouseRoomMst_add(params) { 
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/add',
    method: 'post',
    data: params,
	headers: {
	  'Content-Type': 'application/json;'
	}
  })
}

// /库房管理主表/添加 (含拓展)
export function baseWmsWarehouseRoomMst_addWithExpand(params) { 
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/addWithExpand',
    method: 'post',
    data: params,
	headers: {
	  'Content-Type': 'application/json;'
	}
  })
}

// /库房管理(主表)/编辑
export function baseWmsWarehouseRoomMst_edit(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/edit',
    method: 'post',
    data: params,
  })
}

// /库房管理/编辑(含拓展)/baseWmsWarehouseRoomMst/editWithExpand
export function baseWmsWarehouseRoomMst_editWithExpand(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/editWithExpand',
    method: 'post',
    data: params,
  })
}

//库房管理/删除(含拓展)
export function baseWmsWarehouseRoomMst_delete(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseRoomMst/delete',
    method: 'post',
    params: params,
	headers: {
	  'Content-Type': 'x-www-form-urlencoded;'
	}
  })
}


// /2、库区管理/无分页列表数据
export function baseWmsWarehouseArea_findAll(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/findAll',
    method: 'post',
    data: params
  })
}

// /2、库区管理/条件分页
export function baseWmsWarehouseArea_page(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/page',
    method: 'post',
    data: params,
    headers: {
      'Content-Type': 'application/json;'
    }
  })
}

// /2、库区管理/条件分页2
export function baseWmsWarehouseArea_page2(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/page2',
    method: 'get',
    params: params,
    headers: {
      'Content-Type': 'x-www-form-urlencoded;'
    }
  })
}

// 2、库区管理/添加
export function baseWmsWarehouseArea_add(params) { 
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/add',
    method: 'post',
    data: params,
	headers: {
	  'Content-Type': 'application/json;'
	}
  })
}

// 2、库区管理/编辑
export function baseWmsWarehouseArea_edit(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/edit',
    method: 'post',
    data: params,
  })
}

// 2、库区管理/删除多条 POST
export function baseWmsWarehouseArea_delete(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/delete',
    method: 'post',
    params: params,
	headers: {
	  'Content-Type': 'x-www-form-urlencoded;'
	}
  })
}


// 2、库区管理/根据库存id删除
export function baseWmsWarehouseArea_delByWarehouseId(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseArea/delByWarehouseId',
    method: 'get',
    params: params,
	headers: {
	  'Content-Type': 'x-www-form-urlencoded;'
	}
  })
}

// 3、逻辑区管理/条件分页
export function baseWmsWarehouseLogic_page(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseLogic/page',
    method: 'post',
    data: params,
    headers: {
      'Content-Type': 'application/json;'
    }
  })
}

// 3、逻辑区管理/条件分页
export function baseWmsWarehouseLogic_page2(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseLogic/page2',
    method: 'get',
    params: params,
  })
}

// 3、逻辑区管理/添加
export function baseWmsWarehouseLogic_add(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseLogic/add',
    method: 'post',
    data: params,
    headers: {
      'Content-Type': 'application/json;'
    }
  })
}

// 3、逻辑区管理/编辑
export function baseWmsWarehouseLogic_edit(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseLogic/edit',
    method: 'post',
    data: params,
    headers: {
      'Content-Type': 'application/json;'
    }
  })
}

// 3、逻辑区管理/删除
export function baseWmsWarehouseLogic_delete(params) {
  return request({
    url: upcloud_base_wh + '/baseWmsWarehouseLogic/delete',
    method: 'post',
    params: params,
    headers: {
      'Content-Type': 'x-www-form-urlencoded;'
    }
  })
}

// 仓库/分页查询
export function warehouse_page(params) { 
  return request({
    url: upcloud_base_wh + '/warehouse/page',
    method: 'get',
    params: params,
  })
}

// 仓配中心/分页查询
export function wmsdc_page(params) { 
  return request({
    url: upcloud_base_wh + '/wmsdc/page',
    method: 'get',
    params: params,
  })
}

// 数据字典 /  库别
export function dict_listbytype(params) { 
  return request({
    url: upcloud_base_common + '/dict/listbytype',
    method: 'post',
    params: params,
  })
}
